@@ -15,7 +15,7 @@ import struct
 import pandas as pd
 from pandas import Series,DataFrame
 import matplotlib.pyplot as plt    
-"""
+
 masslistPos = [118.086255,119.089393,121.050872,122.052918,322.048121,323.050718,622.02896,623.031895,922.009798,923.012863,
 1221.990636,1222.99377,1521.971475,1522.97465,1821.952313,1822.955518,2121.933152,2122.936377,
 2421.91399,2422.917231,2721.894828,2722.898082]
@@ -25,7 +25,7 @@ masslistNeg = [112.985587,301.998139,601.978977, 1033.988109, 1333.968947, 1633.
 nomlistPos = [118,322,622,922,1222,1522,1822,2122,2422,2722]
 
 nomlistNeg = [113,302,602,1034,1334,1634,1934,2234,2534,2834]
-"""
+
 
 def read_exported_peaks(filename):
     '''  Read data exported by MassHunterExport "Export peaks" command
@@ -148,9 +148,9 @@ def exportdat2extract(fname,masslist,maxdelta):
     extract_out = profilefindMasses(masslist,profile,maxdelta)
     return extract_out
 
-def get_df_stat(dat_file, cycle_name):
+def get_df_stat(dat_file, cycle_name, deltaDa):
     scans = read_exported_peaks(dat_file)
-    df = profilefindMasses(masslistPos, scans, 5)
+    df = profilefindMasses(masslistPos, scans, deltaDa)
     df['cycle'] = cycle_name
     df_stat = df.describe()
     df_stat_ = df_stat.T
